Installation
=============

**Note**: Currently, the client is only supported under **Python 2.7**.

MacOS / Linux
---------------

Simply run

.. code:: bash

    pip install -U blackfynn

Windows
--------

**Note**: For best results, we recommended running under `Cygwin <https://cygwin.com/install.html>`_ on Windows.


1. Download and `install Python 2.7 <https://www.python.org/downloads/windows/>`_
    - Assuming default install location of ``C:\Python27``
2. Download and install `Microsoft Visual C++ 9.0 Compiler <http://aka.ms/vcpython27>`_
3. Install Blackfynn library: ``C:\Python27\Scripts\pip.exe install -U blackfynn``
4. Command line tool now accessible through ``C:\Python27\Scripts\bf.exe``
